/**
 *
 * @author B.Carre at Polytech Lille
 */

import java.awt.Container;
import java.awt.GridLayout;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.text.DecimalFormat;
import javax.swing.JApplet;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JSlider;
import javax.swing.JTextField;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

@SuppressWarnings("serial")
public class AnemometreApplet extends JApplet {
    // Le systeme a interfacer
    Convertisseur convertisseur = new Convertisseur();

    // Les composants
    private JLabel kmhLabel = new JLabel("KM/H", JLabel.CENTER);
    private JSlider slider = new JSlider(JSlider.HORIZONTAL, 0, 120, 0);
    private JTextField kmh = new JTextField("0.0");
    private JLabel noeudsLabel = new JLabel("NOEUDS", JLabel.CENTER);
    private JTextField noeuds = new JTextField("0.0");
    private JLabel forceLabel = new JLabel("INDICATEUR DE FORCE (ECHELLE DE BEAUFORT) = 0", JLabel.CENTER);
    private JButton raz = new JButton("RAZ");

    @Override
    public void init() {
        // Configuration du slider
        slider.setMajorTickSpacing(10);
        slider.setMinorTickSpacing(1);
        slider.setPaintLabels(true);
        slider.setPaintTicks(true);
        slider.setPaintTrack(false);
        slider.setSnapToTicks(true);
        slider.setOpaque(false);
        // Stategie de layout des composants
        Container cp = getContentPane();
        cp.setLayout(new GridLayout(7, 1));
        // Ajout et initialisation des composants selon cette strategie
        add(this.kmhLabel);
        add(this.slider);
        add(this.kmh);
        add(this.noeudsLabel);
        add(this.noeuds);
        add(this.forceLabel);
        add(this.raz);
        // Dynamique de l'interface
        this.slider.addChangeListener(new KmhSliderListener());
        this.kmh.addActionListener(new KmhListener());
        this.noeuds.addActionListener(new NoeudsListener());
        this.raz.addActionListener(new RAZListener());
    }

    class KmhSliderListener implements ChangeListener {

        public void stateChanged(ChangeEvent event) {
            int vitesse = slider.getValue();
            convertisseur.setKMH(vitesse);
            updateFromSlider();
        }
    }

    class KmhListener implements ActionListener {

        public void actionPerformed(ActionEvent arg0) {
            double vitesse = Double.parseDouble(kmh.getText());
            convertisseur.setKMH(vitesse);
            updateFromDigits();
        }
    }

    class NoeudsListener implements ActionListener {

        public void actionPerformed(ActionEvent event) {
            double vitesse = Double.parseDouble(noeuds.getText());
            convertisseur.setNoeuds(vitesse);
            updateFromDigits();
        }
    }

    void updateFromSlider() {
        this.slider.setValue((int) convertisseur.getKMH());
        this.kmh.setText(String.valueOf(new DecimalFormat("0.00").format(convertisseur.getKMH())));
        this.noeuds.setText(String.valueOf(new DecimalFormat("0.00").format(convertisseur.getNoeuds())));
        this.forceLabel.setText(String.valueOf("INDICATEUR DE FORCE (ECHELLE DE BEAUFORT) = " + convertisseur.getForce()));
    }

    void updateFromDigits() {
        double vitesse = convertisseur.getKMH();
        this.slider.setValue((int) vitesse); // mais approxime ...
        convertisseur.setKMH(vitesse); // retablissement ...
        this.kmh.setText(String.valueOf(new DecimalFormat("0.00").format(convertisseur.getKMH())));
        this.noeuds.setText(String.valueOf(new DecimalFormat("0.00").format(convertisseur.getNoeuds())));
        this.forceLabel.setText(String.valueOf("INDICATEUR DE FORCE (ECHELLE DE BEAUFORT) = " + convertisseur.getForce()));

    }

    class RAZListener implements ActionListener {

        public void actionPerformed(ActionEvent event) {
            slider.setValue(0);
        }

    }
}
