/**
 * Interaction en mode graphique
 * implantation des listeners par lambdas expressions
 * quand c'est possible.
 * 
 * @author B.Carre at Polytech Lille
 * 
 */

import java.awt.Container;
import java.awt.GridLayout;

import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.text.DecimalFormat;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JSlider;
import javax.swing.JTextField;

@SuppressWarnings("serial")
public class AnemometreGraphiqueLambdas extends JFrame {

	// le systeme a interfacer
	Convertisseur convertisseur = new Convertisseur();

	// creation des composants
	private JLabel kmhLabel = new JLabel("KM/H", JLabel.CENTER), noeudsLabel = new JLabel("NOEUDS", JLabel.CENTER),
			forceLabel = new JLabel("INDICATEUR DE FORCE (ECHELLE DE BEAUFORT) = 0", JLabel.CENTER);
	private JTextField kmh = new JTextField("0.0"), noeuds = new JTextField("0.0");
	private JButton raz = new JButton("RAZ");
	private JSlider slider = new JSlider(JSlider.HORIZONTAL, 0, 120, 0);

	public AnemometreGraphiqueLambdas() {
		// Configuration du slider
		slider.setMajorTickSpacing(10);
		slider.setMinorTickSpacing(1);
		slider.setPaintLabels(true);
		slider.setPaintTicks(true);
		slider.setPaintTrack(false);
		slider.setSnapToTicks(true);
		slider.setOpaque(false);
		// choix du LayoutManager
		Container cp = getContentPane();
		cp.setLayout(new GridLayout(7, 1));
		// Ajout des composants
		add(this.kmhLabel);
		add(this.slider);
		add(this.kmh);
		add(this.noeudsLabel);
		add(this.noeuds);
		add(this.forceLabel);
		add(this.raz);
		// Dynamique de l'interface 
		// 1. Lambda expressions possibles
		//    - interfaces fonctionnelles de Listener
		//    - noter la "capture" de this
		slider.addChangeListener(e -> {
			int vitesse = slider.getValue();
			this.convertisseur.setKMH(vitesse);
			this.updateFromSlider();
		});

		kmh.addActionListener(e -> {
			double vitesse = Double.parseDouble(kmh.getText());
			this.convertisseur.setKMH(vitesse);
			this.updateFromDigits();
		});

		noeuds.addActionListener(e -> {
			double vitesse = Double.parseDouble(noeuds.getText());
			this.convertisseur.setNoeuds(vitesse);
			this.updateFromDigits();
		});

		raz.addActionListener(e -> {
			this.slider.setValue(0);
		});

		// 2. Lambda expression impossible
		//    WindowListener a plusieurs methodes, ce n'est pas une interface fonctionnelle
		addWindowListener(new WindowAdapter() {
			public void windowClosing(WindowEvent e) {
				// nothing to save ...
				System.exit(0);
			}
		});

	}

	void updateFromSlider() {
		this.slider.setValue((int) convertisseur.getKMH());
		this.kmh.setText(String.valueOf(new DecimalFormat("0.00").format(convertisseur.getKMH())));
		this.noeuds.setText(String.valueOf(new DecimalFormat("0.00").format(convertisseur.getNoeuds())));
		this.forceLabel
				.setText(String.valueOf("INDICATEUR DE FORCE (ECHELLE DE BEAUFORT) = " + convertisseur.getForce()));
	}

	void updateFromDigits() {
		double vitesse = convertisseur.getKMH();
		this.slider.setValue((int) vitesse); // mais approxime ...
		convertisseur.setKMH(vitesse); // retablissement ...
		this.kmh.setText(String.valueOf(new DecimalFormat("0.00").format(convertisseur.getKMH())));
		this.noeuds.setText(String.valueOf(new DecimalFormat("0.00").format(convertisseur.getNoeuds())));
		this.forceLabel
				.setText(String.valueOf("INDICATEUR DE FORCE (ECHELLE DE BEAUFORT) = " + convertisseur.getForce()));

	}

	public static void main(String[] args) {
		AnemometreGraphiqueLambdas fenetre = new AnemometreGraphiqueLambdas();
		fenetre.setSize(500, 300);
		fenetre.setTitle("ANEMOMETRE");
		fenetre.setVisible(true);
	}
}